#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 aeson
version:              1.5.6.0
visibility:           public
id:                   aeson-1.5.6.0-IA546NaLWlLGqcowhw6tTs
key:                  aeson-1.5.6.0-IA546NaLWlLGqcowhw6tTs
license:              BSD-3-Clause
copyright:
    (c) 2011-2016 Bryan O'\''Sullivan
    (c) 2011 MailRank, Inc.

maintainer:           Adam Bergmark <adam@bergmark.nl>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/haskell/aeson
synopsis:             Fast JSON parsing and encoding
description:
    A JSON parsing and encoding library optimized for ease of use
    and high performance.

    To get started, see the documentation for the @Data.Aeson@ module
    below.

    (A note on naming: in Greek mythology, Aeson was the father of Jason.)

category:             Text, Web, JSON
abi:                  368b2fc6072d4e94c9412f5d5f279a77
exposed:              True
exposed-modules:
    Data.Aeson Data.Aeson.Encode Data.Aeson.Encoding
    Data.Aeson.Encoding.Internal Data.Aeson.Internal
    Data.Aeson.Internal.Time Data.Aeson.Parser
    Data.Aeson.Parser.Internal Data.Aeson.QQ.Simple Data.Aeson.TH
    Data.Aeson.Text Data.Aeson.Types

hidden-modules:
    Data.Aeson.Encoding.Builder Data.Aeson.Internal.Functions
    Data.Aeson.Parser.Unescape Data.Aeson.Parser.Time
    Data.Aeson.Types.FromJSON Data.Aeson.Types.Generic
    Data.Aeson.Types.ToJSON Data.Aeson.Types.Class
    Data.Aeson.Types.Internal Data.Attoparsec.Time
    Data.Attoparsec.Time.Internal Data.Aeson.Parser.UnescapePure

import-dirs:          /usr/lib/ghc-8.10.5/site-local/aeson-1.5.6.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/aeson-1.5.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/aeson-1.5.6.0
hs-libraries:         HSaeson-1.5.6.0-IA546NaLWlLGqcowhw6tTs
depends:
    attoparsec-0.14.1-IwUGXYiDhQIB5nUHrI5Wg8 base-4.14.2.0
    base-compat-batteries-0.11.2-Adi2U3TFDt9D7s2pHONdZC
    bytestring-0.10.12.0 containers-0.6.4.1
    data-fix-0.3.1-D9MFel1sX0UA9T9qsnfRBB deepseq-1.4.4.0
    dlist-1.0-AY7L3vPTTCQEIACGjuCugq ghc-prim-0.6.1
    hashable-1.3.2.0-L2CDkY7lZtECinpkHRj0mo
    primitive-0.7.1.0-H44eQ1j8hQJ3Kj2SFx0Ivh
    scientific-0.3.7.0-Ea1GK6jx8XDEEsfAKxwFym
    strict-0.4.0.1-JMnBD6iPAun9tbAlBpqxyD
    tagged-0.8.6.1-F25vmSN4H5fEaMJYsLgYMV template-haskell-2.16.0.0
    text-1.2.4.1 th-abstraction-0.4.2.0-5X2XqBZ7rCLBwJXut5dQBZ
    these-1.1.1.1-6gES5kDvvXJGGRCQQG0Vwd time-1.9.3
    time-compat-1.9.6-IRFK5lCmLyZ3fyMFVeT95j
    unordered-containers-0.2.14.0-D9MLkVL2jXfKIhE8RrmI8O
    uuid-types-1.0.5-EgNl6lc27W27kXZpOd1nsx
    vector-0.12.3.0-K9OZS5OCy7cE2QKQqSO9mp

haddock-interfaces:   /usr/share/doc/haskell-aeson/html/aeson.haddock
haddock-html:         /usr/share/doc/haskell-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

